pub struct GoogleAnalyticsAdminV1alphaGlobalSiteTag {
pub name: Option<String>,
pub snippet: Option<String>,
}Expand description
Read-only resource with the tag for sending data from a website to a DataStream. Only present for web DataStream resources.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- data streams get global site tag properties (response)
Fields
name: Option<String>Output only. Resource name for this GlobalSiteTag resource. Format: properties/{property_id}/dataStreams/{stream_id}/globalSiteTag Example: “properties/123/dataStreams/456/globalSiteTag”
snippet: Option<String>Immutable. JavaScript code snippet to be pasted as the first item into the head tag of every webpage to measure.