pub struct GoogleAnalyticsAdminV1alphaListConversionEventsResponse {
pub conversion_events: Option<Vec<GoogleAnalyticsAdminV1alphaConversionEvent>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListConversionEvents RPC.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- conversion events list properties (response)
Fields
conversion_events: Option<Vec<GoogleAnalyticsAdminV1alphaConversionEvent>>The requested conversion events
next_page_token: Option<String>A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.