pub struct GoogleAnalyticsAdminV1alphaListDisplayVideo360AdvertiserLinkProposalsResponse {
pub display_video360_advertiser_link_proposals: Option<Vec<GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLinkProposal>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListDisplayVideo360AdvertiserLinkProposals RPC.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
display_video360_advertiser_link_proposals: Option<Vec<GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLinkProposal>>List of DisplayVideo360AdvertiserLinkProposals.
next_page_token: Option<String>A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.